@@ -1,9 +1,17 @@
 from dataclasses import dataclass
+from enum import Enum
 from typing import Optional, Sequence
 
 from derobertis_cv.pltemplates.logo import HasLogo
 
 
+class OrganizationCharacteristics(str, Enum):
+    WARM_WEATHER = 'warm_weather'
+    SMALL_TOWN = 'small_town'
+    MID_SIZE_CITY = 'mid_size_city'
+    LARGE_CITY = 'large_city'
+
+
 @dataclass
 class Organization(HasLogo):
     title: str
@@ -14,6 +22,8 @@ class Organization(HasLogo):
     logo_base64: Optional[str] = None
     logo_fa_icon_class_str: Optional[str] = None
     address_lines: Optional[Sequence[str]] = None
+    city: Optional[str] = None
+    characteristics: Sequence[OrganizationCharacteristics] = tuple()
 
     def __post_init__(self):
         if self.abbreviation is None:
