@@ -27,6 +27,8 @@ class SkillModel(CasedModel, NestedModel, HasLogo):
     primary_category: Optional[Union['SkillModel', str]] = None
 
     def __post_init__(self):
+        if self.primary_category is not None and self.primary_category != 'self':
+            self.parents = (*self.parents, self.primary_category)
         super().__init__()
 
     @property
