@@ -14,6 +14,8 @@ ASSETS_PATH = plbuilder_path('assets')
 assets_path = path_func(ASSETS_PATH)
 IMAGES_PATH = assets_path('images')
 images_path = path_func(IMAGES_PATH)
+PDFS_PATH = assets_path('pdfs')
+pdfs_path = path_func(PDFS_PATH)
 SLIDES_BUILD_PATH = 'Slides'
 slides_build_path = path_func(SLIDES_BUILD_PATH)
 HANDOUTS_BUILD_PATH = 'Handouts'
@@ -28,3 +30,5 @@ DOCUMENTS_SOURCE_PATH = source_path('document')
 documents_source_path = path_func(DOCUMENTS_SOURCE_PATH)
 TEMPLATES_PATH = plbuilder_path('templates')
 templates_path_func = path_func(TEMPLATES_PATH)
+APPLICATIONS_OUT_PATH = 'Applications'
+applications_out_path = path_func(APPLICATIONS_OUT_PATH)
