@@ -1,6 +1,8 @@
 import pyexlatex as pl
 
-NAME = 'Nick DeRobertis'
+FIRST_NAME = 'Nick'
+LAST_NAME = 'DeRobertis'
+NAME = f'{FIRST_NAME} {LAST_NAME}'
 EMAIL = "nick.derobertis@warrington.ufl.edu"
 ADDRESS_LINES = [
     '816 32nd Street',
