@@ -1,6 +1,6 @@
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from enum import Enum
-from typing import Sequence, List, Optional, Union
+from typing import Sequence, List, Optional, Union, Dict
 
 import inflect
 from pyexlatex.logic.format.and_join import join_with_commas_and_and
@@ -8,17 +8,19 @@ from pyexlatex.models.format.text.linespacing import LineSpacing
 from pyexlatex.typing import PyexlatexItems, PyexlatexItem
 import pyexlatex as pl
 
-from derobertis_cv.models.organization import Organization
-from derobertis_cv.plbuild.paths import DOCUMENTS_BUILD_PATH
+from derobertis_cv.models.organization import Organization, OrganizationCharacteristics
+from derobertis_cv.plbuild.paths import DOCUMENTS_BUILD_PATH, images_path
 from derobertis_cv.pldata.authors import Author, AUTHORS
 from derobertis_cv.pldata.constants.authors import ANDY, NIMAL, BAOLIAN
-from derobertis_cv.pldata.constants.contact import SITE_URL, EMAIL, PHONE, ADDRESS_LINES, NAME
+from derobertis_cv.pldata.constants.contact import SITE_URL, EMAIL, PHONE, ADDRESS_LINES, NAME, FIRST_NAME
 from derobertis_cv.pldata.courses.fin_model import get_fin_model_course
 
 
 class ApplicationComponents(str, Enum):
     CV = 'CV'
     JOB_MARKET_PAPER = 'Job market paper'
+    GOVERNMENT_INTERVENTION_PAPER = 'Government intervention paper'
+    INVESTOR_ATTENTION_PAPER = 'Investor attention paper'
     OTHER_RESEARCH = 'Other research work'
     RESEARCH_STATEMENT = 'Research statement'
     TEACHING_STATEMENT = 'Teaching statement'
@@ -26,6 +28,24 @@ class ApplicationComponents(str, Enum):
     TRANSCRIPTS = 'Graduate transcripts'
     EVALUATIONS = 'Teaching evaluations'
     DIVERSITY = 'Diversity statement'
+    COVER_LETTER = 'Cover Letter'
+    REFERENCES = 'References'
+
+    @staticmethod
+    def aggregate(components: Sequence['ApplicationComponents'],
+                  include_references: bool = False) -> List['ApplicationComponents']:
+        out_comps: List['ApplicationComponents'] = []
+        for comp in components:
+            if comp in (
+                ApplicationComponents.GOVERNMENT_INTERVENTION_PAPER,
+                ApplicationComponents.INVESTOR_ATTENTION_PAPER
+            ) and ApplicationComponents.OTHER_RESEARCH not in out_comps:
+                out_comps.append(ApplicationComponents.OTHER_RESEARCH)
+            elif not include_references and comp == ApplicationComponents.REFERENCES:
+                continue
+            else:
+                out_comps.append(comp)
+        return out_comps
 
 
 class ApplicationFocus(str, Enum):
@@ -112,22 +132,28 @@ class CoverLetter:
     font_scale: float = 1
     line_spacing: float = 1
     as_email: bool = False
+    by_email: bool = False
+    file_renames: Optional[Dict[ApplicationComponents, str]] = field(
+        default_factory=lambda: {ApplicationComponents.CV: 'Nick DeRobertis CV'}
+    )
 
     def to_pyexlatex(self, output: bool = True, out_folder: str = DOCUMENTS_BUILD_PATH) -> pl.LetterDocument:
         contents = [
             self.blue,
             self.intro_paragraph,
             *self.desire_content,
-            self.app_package,
+            self.app_package(email=self.as_email),
             self.action_paragraph,
         ]
 
         packages = [
             pl.Package('geometry', modifier_str='margin=0.75in'),
             pl.Package('hyperref', modifier_str='hidelinks'),
+            'graphicx',
         ]
 
         pre_env_contents = []
+        signer_contents = []
 
         if not self.as_email:
             packages.append('fontspec')
@@ -137,6 +163,14 @@ class CoverLetter:
                 ',Ligatures = {Common, TeX}]'
             )
             pre_env_contents.append(pl.Raw(font_str))
+            signer_contents.extend([
+                pl.VSpace(-1.6),
+                pl.Graphic(images_path('signature.png'), width='5cm'),
+                pl.OutputLineBreak(),
+                NAME
+            ])
+        else:
+            signer_contents.extend([pl.Raw(r'\HCode{<br>}'), NAME])
 
         if self.line_spacing != 1:
             packages.extend([
@@ -144,12 +178,15 @@ class CoverLetter:
                 LineSpacing(self.line_spacing)
             ])
 
+        saluation = f'Dear {self.target.person.salutation_name if self.target.person else "Sir or Madam"}:'
+
+
         letter = pl.LetterDocument(
             contents,
             contact_info=[NAME, *ADDRESS_LINES],
             to_contact_info=self.to_contact_info,
-            signer_name=NAME,
-            salutation=f'Dear {self.target.person.salutation_name if self.target.person else "Sir or Madam"}:',
+            signer_name=signer_contents,
+            salutation=saluation,
             packages=packages,
             pre_env_contents=pre_env_contents,
             font_size=11,
@@ -160,9 +197,49 @@ class CoverLetter:
                 letter.to_html(out_folder, outname=f'{self.target.organization.abbreviation} Cover Letter')
             else:
                 letter.to_pdf(out_folder, outname=f'{self.target.organization.abbreviation} Cover Letter')
+            if self.by_email:
+                email_contents = [
+                    saluation,
+                    '',
+                    self.separate_email_intro,
+                    self.app_package(email=True, include_cover_letter=True),
+                    self.separate_email_conclusion,
+                    '\n',
+                    *self.separate_email_signature,
+                ]
+                email_doc = pl.Document(email_contents)
+                email_doc.to_html(out_folder, outname=f'{self.target.organization.abbreviation} Email Body')
 
         return letter
 
+    @property
+    def separate_email_intro(self) -> str:
+        p = inflect.engine()
+        a_position = p.a(self.target.position_name)
+
+        return f"""
+I hope this email finds you well. My name is {NAME} and I would like to submit my application 
+to be {a_position} at {self.target.organization.abbreviation}.
+""".strip()
+
+    @property
+    def separate_email_conclusion(self) -> str:
+        return f"""
+you will also receive supporting reference letters from 
+{self.recommenders_str}. Please do not hesitate to reach out to them.
+If you have any questions, please do not hesitate to contact me by replying to this email 
+or at {PHONE}. 
+""".strip()
+
+    @property
+    def separate_email_signature(self) -> PyexlatexItems:
+        return [
+            'Best Regards,',
+            '',
+            pl.Raw(r'\HCode{<br>}'),
+            FIRST_NAME,
+        ]
+
     @property
     def to_contact_info(self) -> List[str]:
         contact_info = [
@@ -188,7 +265,7 @@ I am writing to express my interest and enthusiasm to be {a_position} at
 {self.target.organization.abbreviation} and to submit my supporting application materials.
 My name is {NAME} and I am a Ph.D. candidate in Finance at the University of Florida (graduating in May 2021).
 During the Ph.D., I produced four working papers, five works 
-in progress, developed and taught two courses across six different semesters with 
+in progress, developed and taught two courses across six different semesters in person and online with 
 up to 4.8/5 evaluations, and created 34 open
 source software projects that improve the efficiency and reproducibility of empirical research{site_highlight}
 In addition to establishing a strong economics and finance foundation
@@ -230,7 +307,7 @@ I want to bring all of these skills along with a strong work ethic to {self.targ
     @property
     def research_overview(self) -> str:
         return """
-My research agenda focuses on financial markets; analyzing the role of both fundamental and behavioral
+My research agenda focuses on financial markets: analyzing the role of both fundamental and behavioral
 information in price discovery, the effects of government intervention, and the performance of assets. 
 My study "Government Equity Capital Market Intervention and Stock Returns" with Andy 
 Naranjo and Mahendrarajah Nimalendran informs central bank personnel about the effects of purchasing 
@@ -277,29 +354,46 @@ web-scraping and API access, work with large data sets, and build
 machine learning models to make predictions and classifications. 
         """
 
-    @property
-    def app_package(self) -> PyexlatexItems:
+    def app_package(self, email: bool = False, include_cover_letter: bool = False) -> PyexlatexItems:
+        included_components = ApplicationComponents.aggregate(self.included_components)
         components: List[Union[ApplicationComponents, str]]
-        if len(self.included_components) < 4:
-            if self.included_components[0] == ApplicationComponents.CV:
-                components = [self.included_components[0]]
+        if len(included_components) < 4:
+            if included_components[0] == ApplicationComponents.CV:
+                components = [included_components[0].value]
             else:
-                components = [self.included_components[0].casefold()]
-            if len(self.included_components) > 1:
-                components.extend([comp.casefold() for comp in self.included_components[1:]])
-            package = [
-                'In addition to this application package that includes my',
+                components = [included_components[0].casefold()]
+            if len(included_components) > 1:
+                components.extend([comp.casefold() for comp in included_components[1:]])
+            if email:
+                package = 'the application package attached to this email'
+            else:
+                package = 'this application package'
+            if include_cover_letter:
+                components.append(ApplicationComponents.COVER_LETTER.casefold())
+
+            app_package = [
+                f'In addition to {package} that includes my',
                 join_with_commas_and_and(components)
             ]
-            return package
+            return app_package
+
+        components = list(included_components)
+
+        if email:
+            intro = 'Attached to this email'
+        else:
+            intro = 'Within this application package'
+
+        if include_cover_letter:
+            components.append(ApplicationComponents.COVER_LETTER.casefold())
 
         included_components_bullets = pl.MultiColumn(
-            pl.UnorderedList([comp.value for comp in self.included_components]),
+            pl.UnorderedList([comp.value if isinstance(comp, ApplicationComponents) else comp for comp in components]),
             3
         )
 
         return [
-            "Within this application package, you will find the following components:",
+            f"{intro}, you will find the following components:",
             pl.VSpace(-0.2),
             included_components_bullets,
             pl.VSpace(-0.5),
@@ -395,4 +489,72 @@ Please contact me at {EMAIL} or {PHONE}.
 
     @property
     def blue(self) -> pl.RGB:
-        return pl.RGB(50, 82, 209, color_name="darkblue")
\ No newline at end of file
+        return pl.RGB(50, 82, 209, color_name="darkblue")
+
+
+@dataclass
+class CoverLetterDesireSection:
+    target: ApplicationTarget
+    focus: ApplicationFocus
+    extra_content: Optional[PyexlatexItems] = None
+
+    @property
+    def default_paragraph(self) -> str:
+        return '\n' + self.professional_paragraph + ' ' + self.personal_sentence + '\n'
+
+    @property
+    def professional_paragraph(self) -> str:
+        if self.target.organization.abbreviation is None:
+            raise ValueError('must have organization abbrevation to create desire paragraph professional portion')
+
+        abbrev_posessive = (
+            f"{self.target.organization.abbreviation}'s"
+            if not self.target.organization.abbreviation.casefold().endswith('s')
+            else f"{self.target.organization.abbreviation}'"
+        )
+
+        if self.focus != ApplicationFocus.ACADEMIC:
+            raise NotImplementedError('need to implement auto desire paragraph for other than academic')
+
+        para = f"""
+My multiple lines of research and strong work ethic will contribute to {abbrev_posessive} goal of preeminence in 
+research. Further, I will contribute to the goals of innovation and transformative, accessible education. 
+It may already be apparent that I am not the typical Finance Ph.D. applicant: I have a much
+larger emphasis on creating open-source software. My commitment to open-source is a commitment to inclusion and 
+diversity: I believe everyone should have access to these tools regardless of their economic position, 
+and that anyone should be able to learn from them, regardless of their location in the world or cultural 
+background. I have already built tools for both research and education, and I want to continue innovating
+at a university that encourages such efforts.
+""".strip()
+
+        return para
+
+    @property
+    def personal_sentence(self) -> str:
+        if not self.target.organization.characteristics:
+            raise ValueError('must pass characteristics to organization to generate default desire personal sentence')
+        if self.target.organization.city is None:
+            raise ValueError('must pass city to organization to generate default desire personal sentence')
+
+        personal_sentence = "On a personal level, my wife and I "
+        if OrganizationCharacteristics.SMALL_TOWN in self.target.organization.characteristics:
+            personal_sentence += 'enjoy outdoor activities'
+        elif OrganizationCharacteristics.MID_SIZE_CITY in self.target.organization.characteristics:
+            personal_sentence += 'have an affinity for mid-side cities'
+        elif OrganizationCharacteristics.LARGE_CITY in self.target.organization.characteristics:
+            personal_sentence += 'have an affinity for larger cities'
+
+        if OrganizationCharacteristics.WARM_WEATHER in self.target.organization.characteristics:
+            personal_sentence += ' and warm weather'
+
+        personal_sentence += f' so {self.target.organization.city} seems like a good fit.'
+        return personal_sentence
+
+    def to_pyexlatex(self) -> PyexlatexItems:
+        if self.extra_content is None:
+            return [self.default_paragraph]
+
+        if isinstance(self.extra_content, (list, tuple)):
+            return [self.default_paragraph, *self.extra_content]
+        else:
+            return [self.default_paragraph, self.extra_content]
