@@ -6,9 +6,12 @@ import pyexlatex as pl
 import pyexlatex.resume as lr
 import pyexlatex.graphics as lg
 from pyexlatex.models.item import ItemBase
+from pyexlatex.models.page.header import remove_header
+from pyexlatex.models.page.style import PageStyle, ThisPageStyle
+from pyexlatex.typing import PyexlatexItems
 
 from derobertis_cv.plbuild.paths import images_path
-from derobertis_cv.pldata.constants.contact import STYLED_SITE
+from derobertis_cv.pldata.constants.contact import STYLED_SITE, NAME, EMAIL, PHONE
 from derobertis_cv.pldata.employment_model import JobIDs
 from derobertis_cv.pldata.jobs import (
     get_professional_jobs,
@@ -75,7 +78,7 @@ class CVModel:
             raise ValueError('cannot have both included and excluded software projects')
 
 
-def get_cv_contents(model: CVModel) -> List[ItemBase]:
+def get_cv_contents(model: CVModel, include_self_image: bool = True) -> List[ItemBase]:
     lr_jobs = [
         job.to_pyexlatex_employment() for job in get_professional_jobs(
             excluded_companies=model.excluded_companies,
@@ -159,14 +162,39 @@ def get_cv_contents(model: CVModel) -> List[ItemBase]:
     }
 
     selected_contents = [
-        pl.Raw(r'\vspace*{-3cm}\vbox{\hspace{13.9cm} \href{https://nickderobertis.com}{\includegraphics[width=3.85cm, height=4cm]{' + images_path('nick-derobertis.png') + '}}}'),
-        pl.Raw(r'\hspace{13.3cm} \parbox[r]{5cm}{\centering See more at ' + STYLED_SITE + '}'),
-        pl.VSpace(-0.6),
+        ThisPageStyle('empty'),
     ]
+
+    if include_self_image:
+        selected_contents.extend([
+            pl.Raw(r'\vspace*{-3cm}\vbox{\hspace{13.9cm} \href{https://nickderobertis.com}{\includegraphics[width=3.85cm, height=4cm]{' + images_path('nick-derobertis.png') + '}}}'),
+            pl.Raw(r'\hspace{13.3cm} \parbox[r]{5cm}{\centering See more at ' + STYLED_SITE + '}'),
+            pl.VSpace(-0.6),
+        ])
+
     for section in model.sections:
         if isinstance(section, ResumeSection):
             selected_contents.append(all_contents[section])
         else:
             selected_contents.append(section)
 
-    return selected_contents
\ No newline at end of file
+    return selected_contents
+
+
+def get_cv_pre_env_contents() -> PyexlatexItems:
+    diamond = pl.Raw(r' $\diamond$ ')
+    footer_parts = [NAME, EMAIL, PHONE, STYLED_SITE]
+    footer = str(diamond).join([str(p) for p in footer_parts])
+
+    return [
+        PageStyle("fancyplain"),
+        remove_header,
+        pl.LeftFooter(footer),
+        pl.CenterFooter(''),
+        pl.RightFooter(pl.ThisPageNumber()),
+        pl.FooterLine()
+    ]
+
+
+def get_cv_packages() -> PyexlatexItems:
+    return ['graphicx', 'fancyhdr']
\ No newline at end of file
