@@ -2,11 +2,12 @@ from copy import deepcopy
 from pyexlatex.logic.format.and_join import join_with_commas_and_and_output_list
 
 RESEARCH_INTERESTS = [
-    'empirical corporate finance',
     'empirical asset pricing',
     'behavioral finance',
+    'alternative assets',
+    'monetary policy',
+    'empirical corporate finance',
     'market microstructure',
-    'monetary policy'
 ]
 
 def get_research_interests():
