@@ -66,7 +66,7 @@ def get_professional_jobs(
         EmploymentModel(
             JobIDs.PARLIAMENT_TUTOR.value,
             [
-                "Assist students with homework, projects, test preparation, papers, research in master's and",
+                "Assist students with homework, projects, test preparation, papers, research in master's and "
                 "undergraduate finance courses",
                 "Teach skills to improve academic performance, including study strategies, "
                 "note-taking skills and approaches to answering test questions"
@@ -103,9 +103,9 @@ def get_academic_jobs(
                 'Conduct full research projects, including project development, data collection, and '
                 'analysis',
                 'Analyze billions of data points of panel- and time-series data using econometric models '
-                'and techniques such as OLS, Logit, Probit, Fama-Macbeth, '
+                'and techniques such as OLS, Logit, Probit, Fama-MacBeth, '
                 'ARIMA, vector autoregression, Granger causality, hazard, quantile, '
-                'PCA, LDA, EFA, CFA, SEM, difference-in-difference, and propensity score matching',
+                'PCA, LDA, EFA, CFA, SEM, difference-in-differences, and propensity score matching',
                 'Predict and classify outcomes using machine learning models such as '
                 'deep learning (multilayer perceptron), SVM, '
                 'K-nearest neighbors, K-means, decision trees, '
@@ -133,7 +133,7 @@ def get_academic_jobs(
             ],
             VCU.title,
             'Graduate Assistant',
-            'Richmond, FL',
+            'Richmond, VA',
             begin_date=datetime.datetime(2013, 9, 1),
             end_date=datetime.datetime(2014, 8, 15),
             courses_taught=vcu_courses,
