@@ -1,6 +1,22 @@
 from derobertis_cv.models.organization import Organization
 from derobertis_cv.pldata.cover_letters.models import ApplicationTarget, HiringManager, Gender
 
+PLACEHOLDER_GOV = Organization(
+    '(Government Organization name)',
+    '(City, state)',
+    abbreviation='(Government Organization abbreviation)',
+    address_lines=[
+        '(Organization division)',
+        '(Street address)',
+        '(City, state, ZIP)',
+    ]
+)
+
+PLACEHOLDER_GOV_TARGET = ApplicationTarget(
+    PLACEHOLDER_GOV,
+    '(Position name)',
+)
+
 SEC_DERA = Organization(
     'U.S. Securities and Exchange Commission',
     'Washington, DC',
