@@ -20,6 +20,14 @@ OTHER = SkillModel('Other', 3)
 # Skills
 PROGRAMMING_SKILL = SkillModel('Programming', 5)
 PRESENTATION_SKILL = SkillModel('presentation', 4)
+COMMUNICATION_SKILL = SkillModel('Communication', 5, parents=(SOFT_SKILLS,))
+CRITICAL_THINKING_SKILL = SkillModel('critical thinking', 5, parents=(SOFT_SKILLS,))
+LEADERSHIP_SKILL = SkillModel('leadership', 4, parents=(SOFT_SKILLS,))
+MULTITASKING_SKILL = SkillModel('multitasking', 5, parents=(SOFT_SKILLS,))
+ORGANIZATION_SKILL = SkillModel('organization', 4, parents=(SOFT_SKILLS,))
+WORK_ETHIC_SKILL = SkillModel('work ethic', 5, parents=(SOFT_SKILLS,))
+TEACHING_SKILL = SkillModel('teaching', 5, parents=(SOFT_SKILLS,))
+ATTENTION_TO_DETAIL_SKILL = SkillModel('attention to detail', 5, parents=(SOFT_SKILLS,))
 SOFTWARE_ARCHITECTURE_SKILL = SkillModel('software architecture', 4, primary_category=PROGRAMMING_SKILL)
 OS_SKILL = SkillModel('operating systems', 3, primary_category=OTHER)
 HARDWARE_SKILL = SkillModel('computer hardware', 3, primary_category=OTHER)
@@ -69,19 +77,19 @@ LINUX_SKILL = SkillModel('Linux', 4, parents=(OS_SKILL,), flexible_case=False, p
 WINDOWS_SKILL = SkillModel('Windows', 4, parents=(OS_SKILL,), flexible_case=False, primary_category=OTHER)
 
 TYPE_SETTING_SKILL = SkillModel('Typesetting', 4, parents=(PRESENTATION_SKILL,))
-WRITING_SKILL= SkillModel('Writing', 4, primary_category=PRESENTATION_SKILL)
+WRITING_SKILL = SkillModel('Writing', 4, parents=(PRESENTATION_SKILL, SOFT_SKILLS))
 RESEARCH_SKILL = SkillModel('Research', 5)
 DATA_SCIENCE_SKILL = SkillModel(
     'Data Science',
-    4,
+    5,
     parents=(PROGRAMMING_SKILL, RESEARCH_SKILL),
     primary_category='self'
 )
 STATISTICS_SKILL = SkillModel('Statistics', 5, parents=(DATA_SCIENCE_SKILL,))
 MODELING_SKILL = SkillModel('Modeling', 4, parents=(DATA_SCIENCE_SKILL,))
 VERSION_CONTORL_SKILL = SkillModel('Version Control', 4, parents=(PROGRAMMING_SKILL,))
-COLLABORATION_SKILL = SkillModel('Collaboration', 5, primary_category=SOFT_SKILLS)
-ENTREPRENEURSHIP_SKILL = SkillModel('Entrepreneurship', 5, primary_category=SOFT_SKILLS)
+COLLABORATION_SKILL = SkillModel('Collaboration', 5, parents=(SOFT_SKILLS,))
+ENTREPRENEURSHIP_SKILL = SkillModel('Entrepreneurship', 5, parents=(SOFT_SKILLS,))
 PARSING_SKILL = SkillModel('Parsing', 4, parents=(PROGRAMMING_SKILL,))
 TIME_SERIES_SKILL = SkillModel('Time-Series', 3, parents=(STATISTICS_SKILL,), primary_category=DATA_SCIENCE_SKILL)
 FORECASTING_SKILL = SkillModel('Forecasting', 3, parents=(TIME_SERIES_SKILL,), primary_category=DATA_SCIENCE_SKILL)
@@ -146,6 +154,14 @@ _SKILLS: List[SkillModel] = [
     WINDOWS_SKILL,
     PRESENTATION_SKILL,
     TYPE_SETTING_SKILL,
+    COMMUNICATION_SKILL,
+    CRITICAL_THINKING_SKILL,
+    LEADERSHIP_SKILL,
+    MULTITASKING_SKILL,
+    ORGANIZATION_SKILL,
+    WORK_ETHIC_SKILL,
+    TEACHING_SKILL,
+    ATTENTION_TO_DETAIL_SKILL,
     WRITING_SKILL,
     RESEARCH_SKILL,
     STATISTICS_SKILL,
@@ -176,11 +192,13 @@ _SKILLS: List[SkillModel] = [
     SkillModel('SQL', 4, parents=(DATABASE_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL),
     SkillModel('Redis', 4, parents=(DATABASE_SKILL,), flexible_case=False, primary_category=FRAMEWORK_SKILL),
     SkillModel('Angular', 4, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False, primary_category=FRAMEWORK_SKILL),
+    SkillModel('Compodoc', 3, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False),
     SkillModel('React', 1, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False, primary_category=FRAMEWORK_SKILL),
     SkillModel('Docker', 4, parents=(DEV_OPS_SKILL,), flexible_case=False),
     SkillModel('LaTeX', 4, parents=(TYPE_SETTING_SKILL, RESEARCH_SKILL), flexible_case=False, primary_category=PRESENTATION_SKILL),
     SkillModel('SAS', 3, parents=(PROGRAMMING_SKILL,), flexible_case=False),
     SkillModel('Stata', 4, parents=(PROGRAMMING_SKILL,), flexible_case=False),
+    SkillModel('R', 2, parents=(PROGRAMMING_SKILL,), flexible_case=False),
     SkillModel('MATLAB', 1, parents=(PROGRAMMING_SKILL,), flexible_case=False),
     SkillModel('NoSQL', 2, parents=(DATABASE_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL),
     SkillModel('Git', 4, parents=(VERSION_CONTORL_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL),
@@ -213,6 +231,10 @@ _SKILLS: List[SkillModel] = [
     SkillModel('Github Actions', 4, parents=(CI_SKILL,), flexible_case=False, primary_category=DEV_OPS_SKILL),
     SkillModel('Gitlab CI', 3, parents=(CI_SKILL,), flexible_case=False, primary_category=DEV_OPS_SKILL),
 
+    SkillModel('supervised learning', 3, parents=(MACHINE_LEARNING_SKILL,), primary_category=DATA_SCIENCE_SKILL),
+    SkillModel('dimensionality reduction', 3, parents=(MACHINE_LEARNING_SKILL,), primary_category=DATA_SCIENCE_SKILL),
+    SkillModel('deep learning', 2, parents=(MACHINE_LEARNING_SKILL,), primary_category=DATA_SCIENCE_SKILL),
+
     SkillModel('econometrics', 4, parents=(STATISTICS_SKILL,), primary_category=DATA_SCIENCE_SKILL),
     SkillModel('project management', 4, primary_category=OTHER),
     SkillModel('Quality assurance', 3, primary_category=OTHER),
@@ -281,12 +303,11 @@ CV_RENAME_SKILLS: Dict[str, str] = {
     'front-end development': 'Front-end dev.',
     'distributed computing': 'Distrib. Computing',
     'application monitoring': 'App Monitoring',
+    'dimensionality reduction': 'Dim. Reduction',
 }
 
 CV_EXCLUDE_SKILLS: List[str] = [
     'research',
-    'collaboration',
-    'entrepreneurship',
 ]
 
 CV_SKILL_SECTION_ORDER: List[str] = [
@@ -295,6 +316,7 @@ CV_SKILL_SECTION_ORDER: List[str] = [
     'Frameworks',
     'Dev-Ops',
     'Presentation',
+    'Soft Skills',
     'Other'
 ]
 
